package com.ufo.hy.agumaster.tool;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;
import java.util.ArrayList;
import java.util.List;

import org.jsoup.Jsoup;
import org.jsoup.nodes.Document;
import org.jsoup.nodes.Element;
import org.jsoup.select.Elements;

import com.ufo.hy.agumaster.entity.Stock;

// https://www.jianshu.com/p/3430f4d0b384
// https://blog.csdn.net/qq_28940573/article/details/99295276
public class IFengCrawler {
	private final String encoding = "utf-8";
	private List<Stock> stockList; 

	public List<Stock> getStockList() {
		return stockList;
	}

	public IFengCrawler(String startPageUrl) {
		stockList=new ArrayList<Stock>();
		String url=startPageUrl;
		
		while(url!=null) {
			//System.out.println(url);
			String html = getUrlHtml(url,encoding);
			Document doc = Jsoup.parse(html,encoding);
			Element divtab01 = doc.getElementsByClass("tab01").last();
			
			Elements trs=divtab01.getElementsByTag("tr");
			for(Element tr:trs) {
				Elements tds=tr.getElementsByTag("td");
				if(tds.size()>2) {
					Element codeElm=tds.get(0).getElementsByTag("a").last();
					Element nameElm=tds.get(1).getElementsByTag("a").last();
					//System.out.println(codeElm.text()+","+nameElm.text());
					
					Stock s=new Stock();
					s.setCode(codeElm.text());
					s.setName(nameElm.text());
					stockList.add(s);
				}
			}
			
			// next page
			Element lastLink=divtab01.getElementsByTag("a").last();			
			if(lastLink.text().equals("下一页")) {
				url="http://app.finance.ifeng.com/list/stock.php"+lastLink.attr("href");
			}else {
				url=null;
			}
		}	
		
		for(Stock s:stockList) {
			System.out.println(s.getCode()+","+s.getName());
		}
		System.out.println(stockList.size());
	}

	private String getUrlHtml(String url, String encoding) {
		StringBuffer sb = new StringBuffer();
		URL urlObj = null;
		URLConnection openConnection = null;
		InputStreamReader isr = null;
		BufferedReader br = null;
		try {
			urlObj = new URL(url);
			openConnection = urlObj.openConnection();
			isr = new InputStreamReader(openConnection.getInputStream(), encoding);
			br = new BufferedReader(isr);
			String temp = null;
			while ((temp = br.readLine()) != null) {
				sb.append(temp + "\n");
			}
		} catch (MalformedURLException e) {
			e.printStackTrace();
		} catch (IOException e) {
			e.printStackTrace();
		} finally {
			try {
				if (isr != null) {
					isr.close();
				}
			} catch (IOException e) {
				e.printStackTrace();
			}
		}
		return sb.toString();
	}

	public static void main(String[] args) {
		// Proxyconfiguration
		System.setProperty("http.proxyHost", "pkg.proxy.prod.jp.local");
		System.setProperty("http.proxyPort", "10080");

		new IFengCrawler("http://app.finance.ifeng.com/list/stock.php?t=hs");
	}
}
